==> community_charts_flutter-1.0.0.tar.gz: CHANGELOG.md <==
# 1.0.0
Initial fork from google/charts.

* Migrated to null-safety.
* Fixed tests to work with null-safety.
* Applied latest flutter analyzer hints.

# 0.12.0
* Add functions to draw horizontal or vertical links onto the dart charts web canvas.
* Add "preserveSelection" functionality to InitialSelection chart Behavior.
* Bug fixes.

# 0.11.0
* Null support
* Update to latest from internal repo

# 0.10.0
* Internal bug fixes
* Bump versions of intl due to pull request

# 0.9.0
* Internal bug fixes
* Bump versions in Gemlock file due to security alerts

# 0.8.1
* Update intl version.

# 0.8.0
* Bug fixes from open source.

# 0.7.0
* Added vertical bar label

# 0.6.0
* Bars can now be rendered on line charts.
* Negative measure values will now be rendered on bar charts as a separate stack from the positive
values.
* Added a Datum Legend, which displays one entry per value in the first series on the chart. This is
 useful for pie and scatter plot charts.
* The AxisPosition enum in RTLSpec was refactored to AxisDirection to better reflect its effect on
swapping the positions of all start and end components, and not just positioning the measure axes.
* Added custom colors for line renderer area skirts and confidence intervals. A new "areaColorFn"
has been added to Series, and corresponding data to the datum. We could not use the fillColorFn for
these elements, because that color is already applied to the internal section of points on line
charts (including highlighter behaviors).

# 0.5.0
* SelectionModelConfig's listener parameter has been renamed to "changeListener". This is a breaking
change. Please rename any existing uses of the "listener" parameter to "changeListener". This was
named in order to add an additional listener "updateListener" that listens to any update requests,
regardless if the selection model has changed.
* CartesianChart's method getMeasureAxis(String axisId) has been changed to
getMeasureAxis({String axisId) so that getting the primary measure axis will not need passing any id
that does not match the secondary measure axis id. This affects users implementing custom behaviors
using the existing method.

# 0.4.0
* Fixed export file to export ChartsBehavior in the Flutter library instead of the one that resides
in community_charts_common. The community_charts_common behavior should not be used except internally in the
community_charts_flutter library. This is a breaking change if you are using community_charts_common behavior.
* Declare compatibility with Dart 2.
* BasicNumericTickFormatterSpec now takes in a callback instead of NumberFormat as the default
constructor. Use named constructor withNumberFormat instead. This is a breaking change.
* BarRendererConfig is no longer default of type String, please change current usage to
BarRendererConfig<String>. This is a breaking change.
* BarTargetLineRendererConfig is no longer default of type String, please change current usage to
BarTargetLineRendererConfig<String>. This is a breaking change.

# 0.3.0
* Simplified API by removing the requirement for specifying the datum type when creating a chart.
For example, previously to construct a bar chart the syntax was 'new BarChart<MyDatumType>()'.
The syntax is now cleaned up to be 'new BarChart()'. Please refer to the
[online gallery](https://google.github.io/charts/flutter/gallery.html) for the correct syntax.
* Added scatter plot charts
* Added tap to hide for legends
* Added support for rendering area skirts to line charts
* Added support for configurable fill colors to bar charts

# 0.2.0

* Update color palette. Please use MaterialPalette instead of QuantumPalette.
* Dart2 fixes

# 0.1.0

Initial release.

==> community_charts_flutter-1.0.1.tar.gz: CHANGELOG.md <==
# 1.0.1
* Removed unused dependencies
* Updated documentation urls

# 1.0.0
Initial fork from google/charts.

* Migrated to null-safety.
* Fixed tests to work with null-safety.
* Applied latest flutter analyzer hints.

# 0.12.0
* Add functions to draw horizontal or vertical links onto the dart charts web canvas.
* Add "preserveSelection" functionality to InitialSelection chart Behavior.
* Bug fixes.

# 0.11.0
* Null support
* Update to latest from internal repo

# 0.10.0
* Internal bug fixes
* Bump versions of intl due to pull request

# 0.9.0
* Internal bug fixes
* Bump versions in Gemlock file due to security alerts

# 0.8.1
* Update intl version.

# 0.8.0
* Bug fixes from open source.

# 0.7.0
* Added vertical bar label

# 0.6.0
* Bars can now be rendered on line charts.
* Negative measure values will now be rendered on bar charts as a separate stack from the positive
values.
* Added a Datum Legend, which displays one entry per value in the first series on the chart. This is
 useful for pie and scatter plot charts.
* The AxisPosition enum in RTLSpec was refactored to AxisDirection to better reflect its effect on
swapping the positions of all start and end components, and not just positioning the measure axes.
* Added custom colors for line renderer area skirts and confidence intervals. A new "areaColorFn"
has been added to Series, and corresponding data to the datum. We could not use the fillColorFn for
these elements, because that color is already applied to the internal section of points on line
charts (including highlighter behaviors).

# 0.5.0
* SelectionModelConfig's listener parameter has been renamed to "changeListener". This is a breaking
change. Please rename any existing uses of the "listener" parameter to "changeListener". This was
named in order to add an additional listener "updateListener" that listens to any update requests,
regardless if the selection model has changed.
* CartesianChart's method getMeasureAxis(String axisId) has been changed to
getMeasureAxis({String axisId) so that getting the primary measure axis will not need passing any id
that does not match the secondary measure axis id. This affects users implementing custom behaviors
using the existing method.

# 0.4.0
* Fixed export file to export ChartsBehavior in the Flutter library instead of the one that resides
in community_charts_common. The community_charts_common behavior should not be used except internally in the
community_charts_flutter library. This is a breaking change if you are using community_charts_common behavior.
* Declare compatibility with Dart 2.
* BasicNumericTickFormatterSpec now takes in a callback instead of NumberFormat as the default
constructor. Use named constructor withNumberFormat instead. This is a breaking change.
* BarRendererConfig is no longer default of type String, please change current usage to
BarRendererConfig<String>. This is a breaking change.
* BarTargetLineRendererConfig is no longer default of type String, please change current usage to
BarTargetLineRendererConfig<String>. This is a breaking change.

# 0.3.0
* Simplified API by removing the requirement for specifying the datum type when creating a chart.
For example, previously to construct a bar chart the syntax was 'new BarChart<MyDatumType>()'.
The syntax is now cleaned up to be 'new BarChart()'. Please refer to the
[online gallery](https://juliansteenbakker.github.io/community_charts/flutter/gallery.html) for the correct syntax.
* Added scatter plot charts
* Added tap to hide for legends
* Added support for rendering area skirts to line charts
* Added support for configurable fill colors to bar charts

# 0.2.0

* Update color palette. Please use MaterialPalette instead of QuantumPalette.
* Dart2 fixes

# 0.1.0

Initial release.
